pub struct ProviderRequest {
pub url: String,
pub headers: Vec<(Cow<'static, str>, Cow<'static, str>)>,
pub body: Value,
pub timeout: Option<Duration>,
}Expand description
Opaque provider-specific request.
This type encapsulates all information needed to make an HTTP request to a provider, without committing to a specific HTTP client library.
Headers use Cow<'static, str> to avoid allocations for common headers.
Fields
url: StringFull URL to send request to
headers: Vec<(Cow<'static, str>, Cow<'static, str>)>HTTP headers (name, value pairs) using Cow to avoid allocations for static strings
body: ValueRequest body (JSON)
timeout: Option<Duration>Optional request timeout override
Implementations
Sourceimpl ProviderRequest
impl ProviderRequest
Sourcepub fn new(url: impl Into<String>) -> ProviderRequest
pub fn new(url: impl Into<String>) -> ProviderRequest
Create a new provider request.
Sourcepub fn with_header(
self,
name: impl Into<String>,
value: impl Into<String>,
) -> ProviderRequest
pub fn with_header( self, name: impl Into<String>, value: impl Into<String>, ) -> ProviderRequest
Add a header with owned strings.
Sourcepub fn with_static_header(
self,
name: &'static str,
value: &'static str,
) -> ProviderRequest
pub fn with_static_header( self, name: &'static str, value: &'static str, ) -> ProviderRequest
Add a header with static strings (zero allocation).
Sourcepub fn with_body(self, body: Value) -> ProviderRequest
pub fn with_body(self, body: Value) -> ProviderRequest
Set the body.
Sourcepub fn with_timeout(self, timeout: Duration) -> ProviderRequest
pub fn with_timeout(self, timeout: Duration) -> ProviderRequest
Set the timeout.